@@ -3,12 +3,11 @@ import re
 import traceback
 from datetime import datetime, timedelta
 from typing import Tuple, List, Any, Optional
-from dateutil import rrule
 from django.core.management.base import BaseCommand, CommandParser
 from django.utils.timezone import now
 from django.conf import settings
 from jutil.dates import last_month, yesterday, TIME_RANGE_NAMES, TIME_STEP_NAMES, this_month, last_year, last_week, \
-    localize_time_range
+    localize_time_range, this_year, this_week, get_time_steps
 from jutil.email import send_email
 import getpass
 from django.utils import translation
@@ -47,10 +46,12 @@ def add_date_range_arguments(parser: CommandParser):
     Ranges:
       --begin BEGIN
       --end END
-      --last-month
       --last-year
-      --this-month
+      --last-month
       --last-week
+      --this-year
+      --this-month
+      --this-week
       --yesterday
       --today
       --prev-90d
@@ -95,14 +96,18 @@ def get_date_range_by_name(name: str, today: Optional[datetime] = None, tz: Any
     """
     if today is None:
         today = datetime.utcnow()
-    if name == 'last_month':
-        return last_month(today, tz)
     if name == 'last_week':
         return last_week(today, tz)
-    if name == 'this_month':
-        return this_month(today, tz)
+    if name == 'last_month':
+        return last_month(today, tz)
     if name == 'last_year':
         return last_year(today, tz)
+    if name == 'this_week':
+        return this_week(today, tz)
+    if name == 'this_month':
+        return this_month(today, tz)
+    if name == 'this_year':
+        return this_year(today, tz)
     if name == 'yesterday':
         return yesterday(today, tz)
     if name == 'today':
@@ -143,21 +148,14 @@ def parse_date_range_arguments(options: dict, default_range: str = 'last_month')
     if options.get('end'):
         end = parse_datetime(options['end'])  # type: ignore
 
-    step_type = None
-    after_end = end
+    step_type = ''
     for step_name in TIME_STEP_NAMES:
         if options.get(step_name):
-            step_type = getattr(rrule, step_name.upper())
-            if rrule.DAILY == step_type:
-                after_end += timedelta(days=1)
-            if rrule.WEEKLY == step_type:
-                after_end += timedelta(days=7)
-            if rrule.MONTHLY == step_type:
-                after_end += timedelta(days=31)
-    steps = None
+            if step_type:
+                raise ValueError('Cannot use --{} and --{} simultaneously'.format(step_type, step_name))
+            step_type = step_name
     if step_type:
-        begins = list(rrule.rrule(step_type, dtstart=begin, until=after_end))
-        steps = [(begins[i], begins[i+1]) for i in range(len(begins)-1)]
-    if steps is None:
+        steps = get_time_steps(step_type, begin, end)
+    else:
         steps = [(begin, end)]
     return begin, end, steps
